==> istio-model-v1beta1-5.11.2-sources.jar: io/fabric8/istio/api/security/v1beta1/ConditionFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ConditionFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.ConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.ConditionFluent<A>{
  public ConditionFluentImpl() {
  }
  public ConditionFluentImpl(io.fabric8.istio.api.security.v1beta1.Condition instance) {
    this.withKey(instance.getKey()); 
    this.withNotValues(instance.getNotValues()); 
    this.withValues(instance.getValues()); 
  }
  private java.lang.String key;
  private java.util.List<java.lang.String> notValues;
  private java.util.List<java.lang.String> values;
  public java.lang.String getKey() {
    return this.key;
  }
  public A withKey(java.lang.String key) {
    this.key=key; return (A) this;
  }
  public java.lang.Boolean hasKey() {
    return this.key != null;
  }
  
  /**
   * Method is deprecated. use withKey instead.
   */
  @java.lang.Deprecated
  public A withNewKey(java.lang.String arg0) {
    return (A)withKey(new String(arg0));
  }
  public A addToNotValues(java.lang.Integer index,java.lang.String item) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    this.notValues.add(index, item);
    return (A)this;
  }
  public A setToNotValues(java.lang.Integer index,java.lang.String item) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    this.notValues.set(index, item); return (A)this;
  }
  public A addToNotValues(java.lang.String... items) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.notValues.add(item);} return (A)this;
  }
  public A addAllToNotValues(java.util.Collection<java.lang.String> items) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.notValues.add(item);} return (A)this;
  }
  public A removeFromNotValues(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.notValues!= null){ this.notValues.remove(item);}} return (A)this;
  }
  public A removeAllFromNotValues(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.notValues!= null){ this.notValues.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNotValues() {
    return this.notValues;
  }
  public java.lang.String getNotValue(java.lang.Integer index) {
    return this.notValues.get(index);
  }
  public java.lang.String getFirstNotValue() {
    return this.notValues.get(0);
  }
  public java.lang.String getLastNotValue() {
    return this.notValues.get(notValues.size() - 1);
  }
  public java.lang.String getMatchingNotValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: notValues) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingNotValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: notValues) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNotValues(java.util.List<java.lang.String> notValues) {
    if (notValues != null) {this.notValues = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : notValues){this.addToNotValues(item);}} else { this.notValues = null;} return (A) this;
  }
  public A withNotValues(java.lang.String... notValues) {
    if (this.notValues != null) {this.notValues.clear();}
    if (notValues != null) {for (java.lang.String item :notValues){ this.addToNotValues(item);}} return (A) this;
  }
  public java.lang.Boolean hasNotValues() {
    return notValues != null && !notValues.isEmpty();
  }
  public A addNewNotValue(java.lang.String arg0) {
    return (A)addToNotValues(new String(arg0));
  }
  public A addToValues(java.lang.Integer index,java.lang.String item) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    this.values.add(index, item);
    return (A)this;
  }
  public A setToValues(java.lang.Integer index,java.lang.String item) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    this.values.set(index, item); return (A)this;
  }
  public A addToValues(java.lang.String... items) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.values.add(item);} return (A)this;
  }
  public A addAllToValues(java.util.Collection<java.lang.String> items) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.values.add(item);} return (A)this;
  }
  public A removeFromValues(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
  }
  public A removeAllFromValues(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getValues() {
    return this.values;
  }
  public java.lang.String getValue(java.lang.Integer index) {
    return this.values.get(index);
  }
  public java.lang.String getFirstValue() {
    return this.values.get(0);
  }
  public java.lang.String getLastValue() {
    return this.values.get(values.size() - 1);
  }
  public java.lang.String getMatchingValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: values) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: values) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withValues(java.util.List<java.lang.String> values) {
    if (values != null) {this.values = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : values){this.addToValues(item);}} else { this.values = null;} return (A) this;
  }
  public A withValues(java.lang.String... values) {
    if (this.values != null) {this.values.clear();}
    if (values != null) {for (java.lang.String item :values){ this.addToValues(item);}} return (A) this;
  }
  public java.lang.Boolean hasValues() {
    return values != null && !values.isEmpty();
  }
  public A addNewValue(java.lang.String arg0) {
    return (A)addToValues(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConditionFluentImpl that = (ConditionFluentImpl) o;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    if (notValues != null ? !notValues.equals(that.notValues) :that.notValues != null) return false;
    if (values != null ? !values.equals(that.values) :that.values != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(key,  notValues,  values,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-5.12.1-sources.jar: io/fabric8/istio/api/security/v1beta1/ConditionFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ConditionFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.ConditionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.ConditionFluent<A>{
  public ConditionFluentImpl() {
  }
  public ConditionFluentImpl(io.fabric8.istio.api.security.v1beta1.Condition instance) {
    this.withKey(instance.getKey()); 
    this.withNotValues(instance.getNotValues()); 
    this.withValues(instance.getValues()); 
  }
  private java.lang.String key;
  private java.util.List<java.lang.String> notValues;
  private java.util.List<java.lang.String> values;
  public java.lang.String getKey() {
    return this.key;
  }
  public A withKey(java.lang.String key) {
    this.key=key; return (A) this;
  }
  public java.lang.Boolean hasKey() {
    return this.key != null;
  }
  
  /**
   * Method is deprecated. use withKey instead.
   */
  @java.lang.Deprecated
  public A withNewKey(java.lang.String arg0) {
    return (A)withKey(new String(arg0));
  }
  public A addToNotValues(java.lang.Integer index,java.lang.String item) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    this.notValues.add(index, item);
    return (A)this;
  }
  public A setToNotValues(java.lang.Integer index,java.lang.String item) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    this.notValues.set(index, item); return (A)this;
  }
  public A addToNotValues(java.lang.String... items) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.notValues.add(item);} return (A)this;
  }
  public A addAllToNotValues(java.util.Collection<java.lang.String> items) {
    if (this.notValues == null) {this.notValues = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.notValues.add(item);} return (A)this;
  }
  public A removeFromNotValues(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.notValues!= null){ this.notValues.remove(item);}} return (A)this;
  }
  public A removeAllFromNotValues(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.notValues!= null){ this.notValues.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getNotValues() {
    return this.notValues;
  }
  public java.lang.String getNotValue(java.lang.Integer index) {
    return this.notValues.get(index);
  }
  public java.lang.String getFirstNotValue() {
    return this.notValues.get(0);
  }
  public java.lang.String getLastNotValue() {
    return this.notValues.get(notValues.size() - 1);
  }
  public java.lang.String getMatchingNotValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: notValues) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingNotValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: notValues) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNotValues(java.util.List<java.lang.String> notValues) {
    if (notValues != null) {this.notValues = new java.util.ArrayList(); for (java.lang.String item : notValues){this.addToNotValues(item);}} else { this.notValues = null;} return (A) this;
  }
  public A withNotValues(java.lang.String... notValues) {
    if (this.notValues != null) {this.notValues.clear();}
    if (notValues != null) {for (java.lang.String item :notValues){ this.addToNotValues(item);}} return (A) this;
  }
  public java.lang.Boolean hasNotValues() {
    return notValues != null && !notValues.isEmpty();
  }
  public A addNewNotValue(java.lang.String arg0) {
    return (A)addToNotValues(new String(arg0));
  }
  public A addToValues(java.lang.Integer index,java.lang.String item) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    this.values.add(index, item);
    return (A)this;
  }
  public A setToValues(java.lang.Integer index,java.lang.String item) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    this.values.set(index, item); return (A)this;
  }
  public A addToValues(java.lang.String... items) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.values.add(item);} return (A)this;
  }
  public A addAllToValues(java.util.Collection<java.lang.String> items) {
    if (this.values == null) {this.values = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.values.add(item);} return (A)this;
  }
  public A removeFromValues(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
  }
  public A removeAllFromValues(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.values!= null){ this.values.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getValues() {
    return this.values;
  }
  public java.lang.String getValue(java.lang.Integer index) {
    return this.values.get(index);
  }
  public java.lang.String getFirstValue() {
    return this.values.get(0);
  }
  public java.lang.String getLastValue() {
    return this.values.get(values.size() - 1);
  }
  public java.lang.String getMatchingValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: values) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingValue(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: values) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withValues(java.util.List<java.lang.String> values) {
    if (values != null) {this.values = new java.util.ArrayList(); for (java.lang.String item : values){this.addToValues(item);}} else { this.values = null;} return (A) this;
  }
  public A withValues(java.lang.String... values) {
    if (this.values != null) {this.values.clear();}
    if (values != null) {for (java.lang.String item :values){ this.addToValues(item);}} return (A) this;
  }
  public java.lang.Boolean hasValues() {
    return values != null && !values.isEmpty();
  }
  public A addNewValue(java.lang.String arg0) {
    return (A)addToValues(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConditionFluentImpl that = (ConditionFluentImpl) o;
    if (key != null ? !key.equals(that.key) :that.key != null) return false;
    if (notValues != null ? !notValues.equals(that.notValues) :that.notValues != null) return false;
    if (values != null ? !values.equals(that.values) :that.values != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(key,  notValues,  values,  super.hashCode());
  }
  
}
